#!/bin/ksh

#**************************************************************
# Author: Sonia Labetoulle
# Contact: Sonia.Labetoulle__at__locean-ipsl.upmc.fr
# $Revision::                                          $ Revision of last commit
# $Author::                                            $ Author of last commit
# $Date::                                              $ Date of last commit
# IPSL (2012)
#  This software is governed by the CeCILL licence see libIGCM/libIGCM_CeCILL.LIC
#
#**************************************************************

function IGCM_ensemble_CastInit
{
  IGCM_debug_PushStack "IGCM_ensemble_CastInit"

  set -A Alpha      A B C D E F G H I J K L M N O P Q R S T U V W X Y Z
  set -A AlphaMonth a b c d e f g h i j k l

  IGCM_sys_Mkdir ${RUN_DIR}

  IGCM_sys_Cp ${SUBMIT_DIR}/config.card   ${RUN_DIR}
  IGCM_sys_Cp ${SUBMIT_DIR}/ensemble.card ${RUN_DIR}
  IGCM_sys_Cp ${SUBMIT_DIR}/Job_*         ${RUN_DIR}
  IGCM_sys_Cp ${SUBMIT_DIR}/run.card.init ${RUN_DIR}

  if [ -f  ${SUBMIT_DIR}/CreatedDir.txt ] ; then
    IGCM_sys_Cp ${SUBMIT_DIR}/CreatedDir.txt ${RUN_DIR}
  fi
  if [ -f  ${SUBMIT_DIR}/Qsub.txt ] ; then
    IGCM_sys_Cp ${SUBMIT_DIR}/Qsub.txt ${RUN_DIR}
  fi

  IGCM_card_DefineVariableFromOption ${FileName} Ens_PERTURB actif
  IGCM_card_DefineVariableFromOption ${FileName} Ens_PERTURB NAME
  IGCM_card_DefineVariableFromOption ${FileName} Ens_PERTURB DEBUT_INIT
  IGCM_card_DefineVariableFromOption ${FileName} Ens_PERTURB FIN_INIT
  IGCM_card_DefineVariableFromOption ${FileName} Ens_PERTURB PERIODICITE
  IGCM_card_DefineArrayFromOption    ${FileName} Ens_PERTURB NONPERIODIC
  IGCM_card_DefineVariableFromOption ${FileName} Ens_PERTURB DUREE
  IGCM_card_DefineArrayFromOption    ${FileName} Ens_PERTURB DUREE_NONPERIODIC
  IGCM_card_DefineVariableFromOption ${FileName} Ens_PERTURB MEMBER
  IGCM_card_DefineArrayFromOption    ${FileName} Ens_PERTURB PERTURB_BIN
  IGCM_card_DefineVariableFromOption ${FileName} Ens_PERTURB INITFROM
  IGCM_card_DefineVariableFromOption ${FileName} Ens_PERTURB INITPATH
  IGCM_card_DefineVariableFromOption config.card UserChoices TagName
  IGCM_card_DefineVariableFromOption config.card UserChoices CalendarType
  IGCM_card_DefineArrayFromSection   config.card ListOfComponents

  IGCM_debug_Print 1 "ACTIVE            = ${ensemble_Ens_PERTURB_ACTIVE}"
  IGCM_debug_Print 1 "NAME              = ${ensemble_Ens_PERTURB_NAME}"
  IGCM_debug_Print 1 "DEBUT_INIT        = ${ensemble_Ens_PERTURB_DEBUT_INIT}"
  IGCM_debug_Print 1 "FIN_INIT          = ${ensemble_Ens_PERTURB_FIN_INIT}"
  IGCM_debug_Print 1 "PERIODICITE       = ${ensemble_Ens_PERTURB_PERIODICITE}"
  IGCM_debug_Print 1 "NONPERIODIC       = ${ensemble_Ens_PERTURB_NONPERIODIC[*]}"
  IGCM_debug_Print 1 "DUREE             = ${ensemble_Ens_PERTURB_DUREE}"
  IGCM_debug_Print 1 "DUREE_NONPERIODIC = ${ensemble_Ens_PERTURB_DUREE_NONPERIODIC[*]}"
  IGCM_debug_Print 1 "MEMBER            = ${ensemble_Ens_PERTURB_MEMBER}"
  IGCM_debug_Print 1 "PERTURB_BIN       = ${ensemble_Ens_PERTURB_PERTURB_BIN[*]}"
  IGCM_debug_Print 1 "INITFROM          = ${ensemble_Ens_PERTURB_INITFROM}"
  IGCM_debug_Print 1 "INITPATH          = ${ensemble_Ens_PERTURB_INITPATH}"
  IGCM_debug_Print 1 "TagName           = ${config_UserChoices_TagName}"
  IGCM_debug_Print 1 "CalendarType      = ${config_UserChoices_CalendarType}"
  IGCM_debug_Print 1 "ListOfComponents  = ${config_ListOfComponents[*]}"

  PerturbExe=${ensemble_Ens_PERTURB_PERTURB_BIN[0]}
  PerturbComp=${ensemble_Ens_PERTURB_PERTURB_BIN[1]}
  PerturbFile=${ensemble_Ens_PERTURB_PERTURB_BIN[2]}
  PerturbVar=${ensemble_Ens_PERTURB_PERTURB_BIN[3]}
  PerturbAmp=${ensemble_Ens_PERTURB_PERTURB_BIN[4]}

  IGCM_debug_Print 1 "PerturbExe  = ${PerturbExe}"
  IGCM_debug_Print 1 "PerturbFile = ${PerturbFile}"
  IGCM_debug_Print 1 "PerturbComp = ${PerturbComp}"
  IGCM_debug_Print 1 "PerturbVar  = ${PerturbVar}"
  IGCM_debug_Print 1 "PerturbAmp  = ${PerturbAmp}"

  # A few checks Period case:

  # ... Check PERIODICITE ...
  case ${ensemble_Ens_PERTURB_PERIODICITE} in
  _0_)
    IGCM_debug_Print 1 "No periodic start"
    CastPeriodicStart=false
    return
    ;;
  *[Yy]|*[Mm])
    CastPeriodicStart=true
    IGCM_debug_Print 1 "Periodic length : ${ensemble_Ens_PERTURB_PERIODICITE}" ;;
  *)
    IGCM_debug_Exit "IGCM_ensemble_CastInit ${ensemble_Ens_PERTURB_PERIODICITE} : invalid PERIODICITE"
    IGCM_debug_Exit "Choose a value in *Y or *M"
    IGCM_debug_Verif_Exit ;;
  esac
# ... Check DUREE ...
  case ${ensemble_Ens_PERTURB_DUREE} in
  *[Yy]|*[Mm])
    IGCM_debug_Print 1 "Periodic duration : ${ensemble_Ens_PERTURB_DUREE}" ;;
  *)
    IGCM_debug_Exit "IGCM_ensemble_CastInit ${ensemble_Ens_PERTURB_DUREE} invalid DUREE"
    IGCM_debug_Exit "Choose a value in choose in *Y or *M"
    IGCM_debug_Verif_Exit ;;
  esac

  # A few checks for the Non-Periodic case:
  DateNum=0
  while [ $DateNum -lt ${#ensemble_Ens_PERTURB_NONPERIODIC[*]} ] ; do

    # - Check DUREE_NONPERIODIC
    case ${ensemble_Ens_PERTURB_DUREE_NONPERIODIC[$DateNum]} in
    _0_)
      IGCM_debug_Print 1 "No non-periodic start"
      CastNonPeriodicStart=false
      return
      ;;
    *[Yy]|*[Mm])
      IGCM_debug_Print 1 "Non-periodic duration : ${ensemble_Ens_PERTURB_DUREE_NONPERIODIC[$DateNum]}"
      CastNonPeriodicStart=true
      ;;
    *)
      IGCM_debug_Exit "IGCM_ensemble_CastInit ${ensemble_Ens_PERTURB_DUREE_NONPERIODIC[$DateNum]} : invalid DUREE"
      IGCM_debug_Exit "choose in *Y or *M"
      IGCM_debug_Verif_Exit ;;
    esac
    (( DateNum = DateNum + 1 ))
  done

  IGCM_debug_PopStack "IGCM_ensemble_CastInit"
}

function IGCM_ensemble_CastPeriodicStarts
{
  IGCM_debug_PushStack "IGCM_ensemble_CastPeriodicStarts"

  echo "Manage periodic starts"

  [ ${CastPeriodicStart} = false ] && return

#.. Manage periodic starts ..
#   ======================

# ... Loop over DateBegin ...
  eval DateBegin=\${ensemble_Ens_PERTURB_DEBUT_INIT}

  while [ ${DateBegin} -le ${ensemble_Ens_PERTURB_FIN_INIT} ] ; do
    IGCM_date_GetYearMonth ${DateBegin} year month

  # - Determine number of day(s) in PERIODICITE
    PeriodLengthInDays=$( IGCM_date_DaysInCurrentPeriod ${DateBegin} ${ensemble_Ens_PERTURB_PERIODICITE} )

  # - Determine number of day(s) in DUREE
    DureeLengthInDays=$(( $( IGCM_date_DaysInCurrentPeriod ${DateBegin} ${ensemble_Ens_PERTURB_DUREE} ) - 1 ))

  # - Determine DateEnd
    (( DateEnd = $( IGCM_date_AddDaysToGregorianDate ${DateBegin} ${DureeLengthInDays} ) ))

  # - Build directory name
    IGCM_ensemble_CastDirectoryName ${ensemble_Ens_PERTURB_NAME} ${ensemble_Ens_PERTURB_PERIODICITE} $year $month $StartDir

  # - Determine RestartDate
    (( Offset = -1 ))
    (( RestartDate = $( IGCM_date_AddDaysToGregorianDate ${DateBegin} ${Offset} ) ))

    IGCM_debug_Print 2 "${DateBegin} => ${DateEnd} : ${StartDir}"
    echo "${DateBegin} ${DateEnd} ${StartDir}" >> CreatedDir.txt

  # - Create directory for current DateBegin
    if [ ! -d  ${StartDir} ] ; then
      IGCM_sys_Mkdir ${SUBMIT_DIR}/${StartDir}
      IGCM_sys_Cd ${SUBMIT_DIR}/${StartDir}
      ln -s ../../.resol .
      ln -s ../../.libmpi .
      IGCM_sys_Cd ${RUN_DIR}
    fi

  # - Create directory in which to store new restart files
    RestartDir=$ARCHIVE/IGCM_IN/${config_UserChoices_TagName}/${StartDir}
    IGCM_sys_MkdirArchive ${RestartDir}

  # - Loop over members
    i=0
    while [ $i -lt ${ensemble_Ens_PERTURB_MEMBER} ] ; do
      MemberDir="${StartDir}${Alpha[$i]}"
      IGCM_debug_Print 3 "${MemberDir}"

      JobName="Job_${MemberDir}"

      pwd
      ls

    # * Create directory if it doesn't exist and copy/link files
      if [ ! -d  ${SUBMIT_DIR}/${StartDir}/${MemberDir} ] ; then
        IGCM_sys_Mkdir ${SUBMIT_DIR}/${StartDir}/${MemberDir}
        #IGCM_sys_Cp -r COMP/ PARAM/ ${StartDir}/${MemberDir}
        IGCM_sys_Cd ${SUBMIT_DIR}/${StartDir}/${MemberDir}
        ln -s ../../COMP
        ln -s ../../PARAM
        ln -s ../../POST
        IGCM_sys_Cd ${RUN_DIR}
        IGCM_sys_Cp config.card run.card.init ${SUBMIT_DIR}/${StartDir}/${MemberDir}
        IGCM_sys_Cp Job_${ensemble_Ens_PERTURB_NAME} ${SUBMIT_DIR}/${StartDir}/${MemberDir}/${JobName}

        echo "cd ${StartDir}/${MemberDir}/ ; ccc_msub ${JobName} ;" >> Qsub.txt

        echo "sed -e 's/PeriodNb=.*/PeriodNb=48/' ${JobName} > ${JobName}.tmp ; " >> Qsub.txt
        echo "mv ${JobName}.tmp ${JobName} ; cd - ;" >> Qsub.txt
      fi

    # * Update files : config.card, Job_, COMP/comp.card
      IGCM_ensemble_CastFilesUpdate ${DateBegin} ${DateEnd} ${RestartDate}

    # * Apply noise on restart file
      IGCM_ensemble_CastPerturbFile

      (( i = i + 1 ))
    done

  # - Next DateBegin
    echo "$DateBegin  $PeriodLengthInDays"
    case ${ensemble_Ens_PERTURB_PERIODICITE} in
    *[Yy]|*[Mm])
      (( DateBegin = $( IGCM_date_AddDaysToGregorianDate ${DateBegin} ${PeriodLengthInDays} ) ))
      ;;
    esac
    echo "New DateBegin = $DateBegin"
    echo "========================================================================"
  done
  IGCM_debug_PopStack "IGCM_ensemble_CastPeriodicStarts"
}

function IGCM_ensemble_CastNonPeriodicStarts
{
  IGCM_debug_PushStack "IGCM_ensemble_CastNonPeriodicStarts"

  #.. Manage non periodic starts => Loop over DateBegin ..
  #   ==========================

  echo "Manage non periodic starts"

  [ ${CastNonPeriodicStart} = false ] && return

  DateNum=0
# ... Loop over ensemble_Ens_PERTURB_NONPERIODIC ...
  echo ">${DateNum}<"
  echo ">${#ensemble_Ens_PERTURB_NONPERIODIC[*]}<"
  while [ $DateNum -lt ${#ensemble_Ens_PERTURB_NONPERIODIC[*]} ] ; do
    DateBegin=${ensemble_Ens_PERTURB_NONPERIODIC[$DateNum]}
    Duree=${ensemble_Ens_PERTURB_DUREE_NONPERIODIC[$DateNum]}
    echo ">${DateBegin}<"
    echo ">${Duree}<"

  # - Determine number of day(s) in DUREE_NONPERIODIC
    IGCM_date_GetYearMonth ${DateBegin} year month
    DureeLengthInDays=$(( $( IGCM_date_DaysInCurrentPeriod ${DateBegin} ${Duree} ) - 1 ))

  # - Build directory name
    echo "========================================================================"
    echo "ensemble_Ens_PERTURB_NAME = ${ensemble_Ens_PERTURB_NAME}"
    IGCM_ensemble_CastDirectoryName ${ensemble_Ens_PERTURB_NAME} ${Duree} $year $month $StartDir

  # - Determine DateEnd
    (( DateEnd = $( IGCM_date_AddDaysToGregorianDate ${DateBegin} ${DureeLengthInDays} ) ))
    echo ">${DateEnd}<"
    echo "tout va bien 1"

  # - Determine RestartDate
    (( Offset = -1 ))
    (( RestartDate = $( IGCM_date_AddDaysToGregorianDate ${DateBegin} ${Offset} ) ))

    IGCM_debug_Print 2 "${DateBegin} => ${DateEnd} : ${StartDir}"

  # -  Does $StartDir already exist ?
    #echo "tout va bien 2" ${StartDir}
    if [ ! -d ${SUBMIT_DIR}/${StartDir} ] ; then
      echo "create dir"
      IGCM_sys_Mkdir ${SUBMIT_DIR}/${StartDir}
      IGCM_sys_Cd ${SUBMIT_DIR}/${StartDir}
      ln -s ../../.resol .
      ln -s ../../.libmpi .
      IGCM_sys_Cd ${RUN_DIR}
      echo "${DateBegin} ${DateEnd} ${StartDir}" >> CreatedDir.txt
    fi
    PeriodDateEnd=$( grep -m1 ${StartDir} CreatedDir.txt | cut -f2 -d\  )

  # - Create directory in which to store new restart files if it does'nt already exist
    RestartDir=$DMFDIR/IGCM_IN/${config_UserChoices_TagName}/${StartDir}
    IGCM_sys_MkdirArchive ${RestartDir}

  # - Loop over members
    i=0
    while [ $i -lt ${ensemble_Ens_PERTURB_MEMBER} ] ; do
      MemberDir="${StartDir}${Alpha[$i]}"
      IGCM_debug_Print 3 "${MemberDir}"

      JobName="Job_${MemberDir}"

    # * Create directory if it doesn't exist and copy files
      if [ ! -d  ${SUBMIT_DIR}/${StartDir}/${MemberDir} ] ; then
        IGCM_sys_Mkdir ${SUBMIT_DIR}/${StartDir}/${MemberDir}
        #IGCM_sys_Cp -r COMP/ PARAM/ ${StartDir}/${MemberDir}
        IGCM_sys_Cd ${SUBMIT_DIR}/${StartDir}/${MemberDir}
        ln -s ../../COMP
        ln -s ../../PARAM
        ln -s ../../POST
        IGCM_sys_Cd ${RUN_DIR}
        IGCM_sys_Cp config.card run.card.init ${SUBMIT_DIR}/${StartDir}/${MemberDir}
        IGCM_sys_Cp Job_${ensemble_Ens_PERTURB_NAME} ${SUBMIT_DIR}/${StartDir}/${MemberDir}/Job_${MemberDir}

        echo "cd ${StartDir}/${MemberDir}/ ; ccc_msub ${JobName} ;" >> Qsub.txt

        echo "sed -e 's/PeriodNb=.*/PeriodNb=48/' ${JobName} > ${JobName}.tmp ; " >> Qsub.txt
        echo "mv ${JobName}.tmp ${JobName} ; cd - ;" >> Qsub.txt
      fi

    # * Update files : config.card, Job_, COMP/comp.card
      echo "${PeriodDateEnd} ? ${DateEnd}"
      if [ ${PeriodDateEnd} -gt ${DateEnd} ] ; then
        DateEnd=${PeriodDateEnd}
      fi
      IGCM_ensemble_CastFilesUpdate ${DateBegin} ${DateEnd} ${RestartDate}

    # * Apply noise on restart file
      IGCM_ensemble_CastPerturbFile
      (( i = i + 1 ))
    done

    (( DateNum = DateNum + 1 ))
  done
  IGCM_debug_PopStack "IGCM_ensemble_CastNonPeriodicStarts"
}

function IGCM_ensemble_CastFilesUpdate
{
  IGCM_debug_PushStack "IGCM_ensemble_CastFilesUpdate"

#  set -vx

  # Debug Print :
  echo
  IGCM_debug_Print 1 "IGCM_ensemble_CastFilesUpdate :"
  echo

  HumanDateBegin=$(   IGCM_date_ConvertFormatToHuman ${1} )
  HumanDateEnd=$(     IGCM_date_ConvertFormatToHuman ${2} )
  HumanRestartDate=$( IGCM_date_ConvertFormatToHuman ${3} )
  # ==> config.card
  IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card Ensemble EnsembleRun 'y'
  IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card Ensemble EnsembleName ${ensemble_Ens_PERTURB_NAME}
  IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card Ensemble EnsembleDate ${StartDir}

  IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card UserChoices JobName   ${MemberDir}
  IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card UserChoices DateBegin ${HumanDateBegin}
  IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card UserChoices DateEnd   ${HumanDateEnd}
  IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card Restarts OverRule "n"

  for Comp in ${config_ListOfComponents[*]} ; do
    IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card ${Comp} Restart "y"
    IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card ${Comp} RestartDate ${HumanRestartDate}
    IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card ${Comp} RestartJobName ${ensemble_Ens_PERTURB_INITFROM}
    IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card ${Comp} RestartPath ${ensemble_Ens_PERTURB_INITPATH}
  done
  # ==> Job
  # SD : to be encapsulated in a sys function
  sed -e "s/\(#MSUB -r \)[A-Za-z0-9]*\( *#.*\)/\1 ${MemberDir} \2/"           \
      -e "s/\(#MSUB -o Script_Output_\)[A-Za-z0-9]*\(\.*\)/\1${MemberDir}\2/" \
      -e "s/\(#MSUB -e Script_Output_\)[A-Za-z0-9]*\(\.*\)/\1${MemberDir}\2/" \
      ${SUBMIT_DIR}/${StartDir}/${MemberDir}/Job_${MemberDir} > Job_${MemberDir}.tmp
  IGCM_sys_Mv Job_${MemberDir}.tmp ${SUBMIT_DIR}/${StartDir}/${MemberDir}/Job_${MemberDir}

  IGCM_debug_PopStack "IGCM_ensemble_CastFilesUpdate"
}

function IGCM_ensemble_CastDirectoryName
{
  IGCM_debug_PushStack "IGCM_ensemble_CastDirectoryName"

  #.. Debug Print ..
  echo
  IGCM_debug_Print 1 "IGCM_ensemble_CastDirectoryName :"
  echo

#  set -vx

  Name=$1
  Duree=$2
  year=$3
  month=$4

  # - Build directory name
  case ${Duree} in
    *Y|*y)
      siecle="$( echo $year | cut -c1-2 )"
      siecle=$( (( $siecle - 18 )) )
      StartYear="${siecle}$( echo $year | cut -c3-4 )"
      StartDir="${Name}${StartYear}"
      ;;
    *M|*m)
      echo $month
      siecle="$( echo $year | cut -c1-2 )"
      siecle=$( (( $siecle - 18 )) )
      StartYear="${siecle}$( echo $year | cut -c3-4 )"
      StartMonth="${AlphaMonth[ (( $month - 1 )) ]}"
      StartDir="${Name}${StartYear}${StartMonth}"
      ;;
  esac

  IGCM_debug_PopStack "IGCM_ensemble_CastDirectoryName"
}

function IGCM_ensemble_CastPerturbFile
{
  IGCM_debug_PushStack "IGCM_ensemble_CastPerturbFile"

  #.. Debug Print ..
  echo
  IGCM_debug_Print 1 "IGCM_ensemble_CastPerturbFile :"
  echo

  #.. FileIn ? => RestartDate ..
  DirIn="${ensemble_Ens_PERTURB_INITPATH}/${ensemble_Ens_PERTURB_INITFROM}/${PerturbComp}/Restart"
  FileIn="${PerturbComp}_${ensemble_Ens_PERTURB_INITFROM}_${RestartDate}_${PerturbFile}.nc"
  DirOut="${RestartDir}/${MemberDir}/${PerturbComp}/Restart"
#  FileOut="${ensemble_Ens_PERTURB_INITFROM}_${RestartDate}_${PerturbFile}_${MemberDir}.nc"
#  FileOut=${FileIn}
  FileOut="${MemberDir}_${RestartDate}_${PerturbFile}.nc"
  IGCM_debug_Print 1 "FileIn  = ${DirIn}/${FileIn}"
  IGCM_debug_Print 1 "FileOut = ${DirOut}/${FileOut}"

  # * Create member restart directory
  IGCM_sys_TestDirArchive ${DirOut}
  RET=$?
  if [ $RET -gt 0 ] ; then
    IGCM_sys_MkdirArchive ${DirOut}
  fi

  IGCM_sys_TestFileArchive ${DirOut}/${FileOut}
  RET=$?
  if [ $RET -gt 0 ] ; then
#    ${PerturbExe} ${DirIn}/${FileIn} ${DirOut}/${FileOut} \
#                  ${PerturbVar} ${PerturbAmp}
#    IGCM_sys_Cp ${DirIn}/${FileIn} ${DirOut}/${FileOut}
#    IGCM_sys_Chmod u+w ${DirOut}/${FileOut}
#    ${PerturbExe} ${DirOut}/${FileOut} ${PerturbVar} ${PerturbAmp}
    IGCM_sys_Get ${DirIn}/${FileIn} ${RUN_DIR}/${FileOut}
    IGCM_sys_Chmod 744 ${RUN_DIR}/${FileOut}

    ${PerturbExe} ${RUN_DIR}/${FileOut} ${PerturbVar} ${PerturbAmp}
    if [ $? -ne 0 ] ; then
      echo "Abend $( basename ${PerturbExe} )"
      return
    fi

    IGCM_sys_Put_Out ${RUN_DIR}/${FileOut} ${DirOut}/ 744

#    IGCM_sys_Cd ${DirOut}
#    ln -s ${DirIn}/${ensemble_Ens_PERTURB_INITFROM}_${RestartDate}_flxat.nc ${MemberDir}_${RestartDate}_flxat.nc
#    IGCM_sys_Cd -
    IGCM_sys_RshArchive "cd ${DirOut} ; ln -s ${DirIn}/${ensemble_Ens_PERTURB_INITFROM}_${RestartDate}_flxat.nc ${MemberDir}_${RestartDate}_flxat.nc"
  fi

  #.. Update config.card..
  IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card ${PerturbComp} Restart "y"
  IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card ${PerturbComp} RestartDate    ${HumanRestartDate}
  IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card ${PerturbComp} RestartJobName ${MemberDir}
  IGCM_card_WriteOption ${SUBMIT_DIR}/${StartDir}/${MemberDir}/config.card ${PerturbComp} RestartPath    ${RestartDir}/

  IGCM_debug_PopStack "IGCM_ensemble_CastPerturbFile"
}
